==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storagecache/kotlin/inputs/CacheUsernameDownloadSettingsCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagecache.kotlin.inputs

import com.pulumi.azurenative.storagecache.inputs.CacheUsernameDownloadSettingsCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * When present, these are the credentials for the secure LDAP connection.
 * @property bindDn The Bind Distinguished Name identity to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
 * @property bindPassword The Bind password to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
 */
public data class CacheUsernameDownloadSettingsCredentialsArgs(
    public val bindDn: Output<String>? = null,
    public val bindPassword: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.storagecache.inputs.CacheUsernameDownloadSettingsCredentialsArgs> {
    override fun toJava():
        com.pulumi.azurenative.storagecache.inputs.CacheUsernameDownloadSettingsCredentialsArgs =
        com.pulumi.azurenative.storagecache.inputs.CacheUsernameDownloadSettingsCredentialsArgs.builder()
            .bindDn(bindDn?.applyValue({ args0 -> args0 }))
            .bindPassword(bindPassword?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CacheUsernameDownloadSettingsCredentialsArgs].
 */
@PulumiTagMarker
public class CacheUsernameDownloadSettingsCredentialsArgsBuilder internal constructor() {
    private var bindDn: Output<String>? = null

    private var bindPassword: Output<String>? = null

    /**
     * @param value The Bind Distinguished Name identity to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
     */
    @JvmName("cnbstsgobtkxflwb")
    public suspend fun bindDn(`value`: Output<String>) {
        this.bindDn = value
    }

    /**
     * @param value The Bind password to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
     */
    @JvmName("apbmsrpasyrdkabt")
    public suspend fun bindPassword(`value`: Output<String>) {
        this.bindPassword = value
    }

    /**
     * @param value The Bind Distinguished Name identity to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
     */
    @JvmName("pjmjeschywkcecrp")
    public suspend fun bindDn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bindDn = mapped
    }

    /**
     * @param value The Bind password to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
     */
    @JvmName("bsafrdyakykangeb")
    public suspend fun bindPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bindPassword = mapped
    }

    internal fun build(): CacheUsernameDownloadSettingsCredentialsArgs =
        CacheUsernameDownloadSettingsCredentialsArgs(
            bindDn = bindDn,
            bindPassword = bindPassword,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storagecache/kotlin/inputs/CacheUsernameDownloadSettingsCredentialsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storagecache.kotlin.inputs

import com.pulumi.azurenative.storagecache.inputs.CacheUsernameDownloadSettingsCredentialsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * When present, these are the credentials for the secure LDAP connection.
 * @property bindDn The Bind Distinguished Name identity to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
 * @property bindPassword The Bind password to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
 */
public data class CacheUsernameDownloadSettingsCredentialsArgs(
    public val bindDn: Output<String>? = null,
    public val bindPassword: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.storagecache.inputs.CacheUsernameDownloadSettingsCredentialsArgs> {
    override fun toJava():
        com.pulumi.azurenative.storagecache.inputs.CacheUsernameDownloadSettingsCredentialsArgs =
        com.pulumi.azurenative.storagecache.inputs.CacheUsernameDownloadSettingsCredentialsArgs.builder()
            .bindDn(bindDn?.applyValue({ args0 -> args0 }))
            .bindPassword(bindPassword?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CacheUsernameDownloadSettingsCredentialsArgs].
 */
@PulumiTagMarker
public class CacheUsernameDownloadSettingsCredentialsArgsBuilder internal constructor() {
    private var bindDn: Output<String>? = null

    private var bindPassword: Output<String>? = null

    /**
     * @param value The Bind Distinguished Name identity to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
     */
    @JvmName("nrhhphcmfbxlidnj")
    public suspend fun bindDn(`value`: Output<String>) {
        this.bindDn = value
    }

    /**
     * @param value The Bind password to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
     */
    @JvmName("uywjmevlvbjtvwxe")
    public suspend fun bindPassword(`value`: Output<String>) {
        this.bindPassword = value
    }

    /**
     * @param value The Bind Distinguished Name identity to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
     */
    @JvmName("ambontcwudciodst")
    public suspend fun bindDn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bindDn = mapped
    }

    /**
     * @param value The Bind password to be used in the secure LDAP connection. This value is stored encrypted and not returned on response.
     */
    @JvmName("eypiwmlngptnwpsg")
    public suspend fun bindPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bindPassword = mapped
    }

    internal fun build(): CacheUsernameDownloadSettingsCredentialsArgs =
        CacheUsernameDownloadSettingsCredentialsArgs(
            bindDn = bindDn,
            bindPassword = bindPassword,
        )
}
